let fs = require('fs');
let path = require('path');

let commonConfig = {
  coverageReporters: ['json', 'html', 'json-summary', 'text'],
  collectCoverage: true,
  transform: {
    '^.+\\.(js|jsx)$': path.resolve(__dirname, '..', 'jsPreprocessor.js'),
    '^.+\\.css$': path.resolve(__dirname, '..', 'cssPreprocessor.js'),
    '^(?!.*\\.(js|jsx|css|json)$)': path.resolve(
      __dirname,
      '..',
      'otherFilesPreprocessor.js'
    )
  },
  moduleFileExtensions: ['js'],
  globals: {
    DEVELOPMENT: true,
    DOCS: false,
    TEST: true
  }
};

module.exports = function(appFolder, forCommittedFiles = false) {
  let appPath = fs.realpathSync(process.cwd());
  if (forCommittedFiles) {
    return Object.assign({}, commonConfig, {
      coverageDirectory: path.resolve(appPath, 'commitCoverage'),
      testResultsProcessor: path.resolve(__dirname, '..', 'coverageResult.js')
    });
  }

  return Object.assign({}, commonConfig, {
    rootDir: appPath,
    testPathIgnorePatterns: ['/node_modules/', 'docs'],
    unmockedModulePathPatterns: ['__tests__', 'node_modules', '.*'],
    testPathDirs: [`<rootDir>/${appFolder}/`],
    testRegex: '(/__tests__/.*|\\.(test|spec))\\.(jsx|js|json|node)$',
    moduleNameMapper: {
      '\\.(css|less)$': 'identity-obj-proxy'
    },
    testResultsProcessor: path.resolve(__dirname, '..', 'result.js'),
    setupFiles: [path.resolve(__dirname, '..', 'setup.js')],
    moduleDirectories: [
      path.resolve(__dirname, '..', '..', 'node_modules'),
      'node_modules'
    ]
  });
};
